"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.InitCommand = exports.DEFAULT_PROCESS_NAME = void 0;
var _clipanion = require("clipanion");
var _config = require("@verdaccio/config");
var _core = require("@verdaccio/core");
var _logger = require("@verdaccio/logger");
var _nodeApi = require("@verdaccio/node-api");
const DEFAULT_PROCESS_NAME = exports.DEFAULT_PROCESS_NAME = 'verdaccio';
class InitCommand extends _clipanion.Command {
  static paths = [_clipanion.Command.Default];
  port = _clipanion.Option.String('-l,-p,--listen,--port', {
    description: 'host:port number to listen on (default: localhost:4873)'
  });

  // eslint-disable-next-line
  static usage = _clipanion.Command.Usage({
    description: `launch the server`,
    details: `
      This start the registry in the default port.

      When used without arguments, it:

      - bootstrap the server at the port  \`4873\`

      The optional arguments are:

      - \`-l | --listen | -p | --port\` to switch the default server port,
      - \`-c | --config\` to define a different configuration path location,

    `,
    examples: [[`Runs the server with the default configuration`, `verdaccio`], [`Runs the server in the port 5000`, `verdaccio --listen 5000`], [`Runs the server by using a different absolute location of the configuration file`, `verdaccio --config /home/user/verdaccio/config.yaml`]]
  });
  config = _clipanion.Option.String('-c,--config', {
    description: 'use this configuration file (default: ./config.yaml)'
  });
  initLogger(logConfig) {
    if (logConfig.logs) {
      logConfig.log = logConfig.logs;
      _core.warningUtils.emit(_core.warningUtils.Codes.VERWAR002);
    }
    (0, _logger.setup)(logConfig.log);
  }
  async execute() {
    try {
      const configPathLocation = (0, _config.findConfigFile)(this.config);
      const configParsed = (0, _config.parseConfigFile)(configPathLocation);
      this.initLogger(configParsed);
      const {
        web
      } = configParsed;
      process.title = (web === null || web === void 0 ? void 0 : web.title) || DEFAULT_PROCESS_NAME;
      const {
        version,
        name
      } = require('../../package.json');
      await (0, _nodeApi.initServer)(configParsed, this.port, version, name);
      _logger.logger.info('server started');
    } catch (err) {
      console.error(err);
      process.exit(1);
    }
  }
}
exports.InitCommand = InitCommand;
//# sourceMappingURL=init.js.map